#!/bin/bash

. /serwer/serwer.conf

# zalaczenie forwardingu w kernelu
echo 1 > /proc/sys/net/ipv4/ip_forward

# podniesienie IMQ
$IP link set imq0 up
$IP link set imq1 up
$IP link set imq2 up

# czyszczenie lancuchow, tabel, kolejek

$IPTABLES -F
$IPTABLES -Z
$IPTABLES -X

####  FUNKCJE  ####

auth(){

if [ ${2} != "0" ]; then

    if [ `expr index ${2} ,` != "0" ]; then
       
        mac=`echo ${2} | cut -d',' -f 1`; x=2
					   
        while [ $mac ]; do

	    mac=`echo $mac | tr [[:lower:]] [[:upper:]]`
	    $IPTABLES -A FORWARD -s ${1} -m mac --mac-source $mac -j ACCEPT
    	    mac=`echo ${2} | cut -d',' -f $x`
    	    x=$((${x}+1))
	    
	done
														   
    else

	mac=`echo ${2} | tr [[:lower:]] [[:upper:]]`
	$IPTABLES -A FORWARD -s ${1} -m mac --mac-source ${mac} -j ACCEPT															   
    																       
    fi

fi

}

####  KONIEC FUNKCJI  ####

# ruch wychodzacy z serwera oraz localhost
$IPTABLES -A INPUT -i lo -j ACCEPT
$IPTABLES -A OUTPUT -o lo -j ACCEPT
$IPTABLES -A OUTPUT -m state ! --state invalid -j ACCEPT

# INPUT
$IPTABLES -A INPUT -m state --state ESTABLISHED -j ACCEPT
$IPTABLES -A INPUT -m state --state RELATED -j ACCEPT
$IPTABLES -A INPUT -p icmp -f -j DROP
$IPTABLES -A INPUT -p icmp -m pkttype --pkt-type broadcast -j DROP
$IPTABLES -A INPUT -p icmp --icmp-type echo-request -m length --length 28:4096 -j ACCEPT

# autoryzowany dostep tylko z pliku dostep.conf
grep "^[^#]" ${DOSTEP} | while read IP OPIS; do
    $IPTABLES -A INPUT -s $IP -p tcp --dport 20 -j ACCEPT
    $IPTABLES -A INPUT -s $IP -p tcp --dport 21 -j ACCEPT
    $IPTABLES -A INPUT -s $IP -p tcp --sport 1024: --dport 22 -m state --state NEW -j ACCEPT
    $IPTABLES -A INPUT -s $IP -m state --state NEW -p tcp --sport 1024: --dport 80 -j ACCEPT
    $IPTABLES -A INPUT -s $IP -m state --state NEW -p tcp --sport 1024: --dport 53 -j ACCEPT
    $IPTABLES -A INPUT -s $IP -m state --state NEW -p udp --sport 1024: --dport 53 -j ACCEPT
done

# dns input
$IPTABLES -A INPUT -s $INTNET1 -m state --state NEW -p tcp --sport 1024: --dport 53 -j ACCEPT
$IPTABLES -A INPUT -s $INTNET1 -m state --state NEW -p udp --sport 1024: --dport 53 -j ACCEPT
$IPTABLES -A INPUT -s $VPNNET1 -m state --state NEW -p tcp --sport 1024: --dport 53 -j ACCEPT
$IPTABLES -A INPUT -s $VPNNET1 -m state --state NEW -p udp --sport 1024: --dport 53 -j ACCEPT
$IPTABLES -A INPUT -s $NOAUTH -m state --state NEW -p tcp --sport 1024: --dport 53 -j ACCEPT
$IPTABLES -A INPUT -s $NOAUTH -m state --state NEW -p udp --sport 1024: --dport 53 -j ACCEPT

# serwer komunikatow
$IPTABLES -A INPUT -s $INTNET1 -m state --state NEW -p tcp --sport 1024: --dport 200 -j ACCEPT
$IPTABLES -A INPUT -s $INTNET1 -m state --state NEW -p tcp --sport 1024: --dport 201 -j ACCEPT
$IPTABLES -A INPUT -s $VPNNET1 -m state --state NEW -p tcp --sport 1024: --dport 200 -j ACCEPT
$IPTABLES -A INPUT -s $VPNNET1 -m state --state NEW -p tcp --sport 1024: --dport 201 -j ACCEPT
$IPTABLES -A INPUT -s $NOAUTH -m state --state NEW -p tcp --sport 1024: --dport 202 -j ACCEPT

# dhcpd
$IPTABLES -A INPUT -i $INTDEV1 -p tcp --dport 67 -m state --state NEW -j ACCEPT
$IPTABLES -A INPUT -i $INTDEV1 -p udp --dport 67 -m state --state NEW -j ACCEPT
$IPTABLES -A INPUT -i $INTDEV1 -p tcp --dport 68 -m state --state NEW -j ACCEPT
$IPTABLES -A INPUT -i $INTDEV1 -p udp --dport 68 -m state --state NEW -j ACCEPT

# pptp - vpn
$IPTABLES -A INPUT -m state --state NEW -p tcp --dport 1723 -j ACCEPT

##  FORWARD - ruch od/do klientow  ##

# blokada nieprawidlowego ruchu
$IPTABLES -A FORWARD -m state --state invalid -j DROP

# problemy z MTU
$IPTABLES -A FORWARD -p tcp --tcp-flags SYN,RST SYN -j TCPMSS --clamp-mss-to-pmtu

# dns forward
$IPTABLES -A FORWARD -p tcp --dport 53 -j ACCEPT
$IPTABLES -A FORWARD -p udp --dport 53 -j ACCEPT
$IPTABLES -A FORWARD -p tcp --sport 53 -j ACCEPT
$IPTABLES -A FORWARD -p udp --sport 53 -j ACCEPT

# blokada otoczenia sieciowego
$IPTABLES -A FORWARD -p tcp --dport 135:139 -j DROP
$IPTABLES -A FORWARD -p tcp --dport 135:139 -j DROP
$IPTABLES -A FORWARD -p udp --sport 135:139 -j DROP
$IPTABLES -A FORWARD -p udp --sport 135:139 -j DROP
$IPTABLES -A FORWARD -p tcp --dport 445 -j DROP
$IPTABLES -A FORWARD -p tcp --dport 445 -j DROP
$IPTABLES -A FORWARD -p udp --sport 445 -j DROP
$IPTABLES -A FORWARD -p udp --sport 445 -j DROP

# limit polaczen na portach powyzej 1024
$IPTABLES -A FORWARD -s $INTNET1 -p tcp --dport 1024: -m connlimit --connlimit-above $CONNLIMIT --connlimit-mask 32 -j REJECT --reject-with tcp-reset
$IPTABLES -A FORWARD -s $VPNNET1 -p tcp --dport 1024: -m connlimit --connlimit-above $CONNLIMIT --connlimit-mask 32 -j REJECT --reject-with tcp-reset

# filtrowanie SPAMu
$IPTABLES -N SPAM
$IPTABLES -A FORWARD -s $INTNET1 -p tcp --dport 25 -m state --state NEW -j SPAM
$IPTABLES -A FORWARD -s $VPNNET1 -p tcp --dport 25 -m state --state NEW -j SPAM
$IPTABLES -A SPAM -m recent --update --seconds 3 --name smtp -j DROP
$IPTABLES -A SPAM -m recent --set --name smtp -j ACCEPT

# akceptacja polaczen wychodzacych do klientow
$IPTABLES -A FORWARD -d $INTNET1 -j ACCEPT
$IPTABLES -A FORWARD -d $VPNNET1 -j ACCEPT

# akceptacja polaczen do urzadzen
$IPTABLES -A FORWARD -s $HWNET1 -j ACCEPT
$IPTABLES -A FORWARD -d $HWNET1 -j ACCEPT

# panel - internet, predkosci
grep "^[^#]" ${PANEL} | while read IP DOWN UP NDOWN NUP BLOK AUTHMAC; do
    case "${BLOK}" in
	0)
	    if [ $AUTHMAC != "00:00:00:00:00:00" ]; then
        	auth $IP $AUTHMAC
            fi
            $IPTABLES -A FORWARD -i ppp+ -s $IP -j ACCEPT
        ;;
        1)
	    if [ $AUTHMAC != "00:00:00:00:00:00" ]; then
        	auth $IP $AUTHMAC
            fi
            $IPTABLES -A FORWARD -i ppp+ -s $IP -j ACCEPT
        ;;
    esac
done

# DROP DLA RESZTY
$IPTABLES -A INPUT -j DROP
$IPTABLES -A FORWARD -j DROP
$IPTABLES -A OUTPUT -j DROP
